pub enum MirrorError {
Sql(Error),
Json(Error),
QueryNotReadOnly(String),
UnknownResource {
resource: String,
},
UnknownSource(String),
Kernel(KernelError),
Other(Error),
}Expand description
All errors produced by the mirror.
Variants
Sql(Error)
Underlying SQLite / sqlx error.
Json(Error)
JSON (de)serialization failed.
QueryNotReadOnly(String)
The query API rejected the supplied SQL because it is not a
read-only SELECT / WITH / PRAGMA statement.
UnknownResource
A source returned a delta for a resource that has not been pre-registered with the store.
UnknownSource(String)
A source was requested by id but is not registered with the
Syncer.
Kernel(KernelError)
Wrapped oxide-k kernel error (bus / registry).
Other(Error)
Anything else.